#
# spec file for package armnn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Disable LTO until UnitTests passes with LTO enabled - https://github.com/ARM-software/armnn/issues/623
%define _lto_cflags %{nil}

# Disable Python binding for now
%bcond_with PyArmnn

%define target opencl%{nil}
%if "%{target}" != ""
%define package_suffix -%{target}
%endif
# Compute library has neon enabled for aarch64 only
%ifarch aarch64
%bcond_without compute_neon
%else
%bcond_with compute_neon
%endif
%if "%{target}" == "opencl"
%bcond_without compute_cl
%else
%bcond_with compute_cl
%endif
# stb-devel is available on Leap 15.1+
%if 0%{?suse_version} > 1500 || ( 0%{?sle_version} > 150000 && 0%{?is_opensuse} )
%bcond_without armnn_tests
%else
%bcond_with armnn_tests
%endif
# flatbuffers-devel is available on Leap 15.2+/SLE15SP2+
# But tensorflow-lite >= 2.10 is only avaialble on Tumbleweed
%if 0%{?suse_version} > 1500
%bcond_without armnn_flatbuffers
%else
%bcond_with armnn_flatbuffers
%endif
# ONNX is available on Leap 15.2+/SLE15SP2+, but there is a compatibility issue
# with ONNX 1.7.0 in Tumbleweed - https://github.com/ARM-software/armnn/issues/419
%if 0%{?sle_version} >= 150200
%bcond_without armnn_onnx
%else
%bcond_with armnn_onnx
%endif
%define version_major 24
%define version_minor 11
%define version_lib 34
%define version_lib_testutils 3
%define version_lib_tfliteparser 24
%define version_lib_onnxparser 24
Name:           armnn%{?package_suffix}
Version:        %{version_major}.%{version_minor}
Release:        1.4
Summary:        Arm NN SDK enables machine learning workloads on power-efficient devices
License:        MIT
Group:          Development/Libraries/Other
URL:            https://developer.arm.com/products/processors/machine-learning/arm-nn
Source0:        https://github.com/ARM-software/armnn/archive/v%{version}.tar.gz#/armnn-%{version}.tar.gz
Source1:        armnn-rpmlintrc
BuildRequires:  ComputeLibrary-devel >= %{version_major}.%{version_minor}
BuildRequires:  cmake >= 3.22
BuildRequires:  gcc-c++
BuildRequires:  protobuf-devel
BuildRequires:  python-rpm-macros
BuildRequires:  valgrind-devel
BuildRequires:  vim
# Make armnn-opencl pulls lib*-opencl, and armnn pulls non opencl libs
Requires:       libarmnn%{version_lib}%{?package_suffix} = %{version}
ExcludeArch:    %ix86
%if 0%{?suse_version} < 1330
BuildRequires:  boost-devel >= 1.59
%else
BuildRequires:  libboost_filesystem-devel >= 1.59
BuildRequires:  libboost_program_options-devel >= 1.59
BuildRequires:  libboost_system-devel >= 1.59
BuildRequires:  libboost_test-devel >= 1.59
%endif
%if %{with armnn_flatbuffers}
BuildRequires:  flatbuffers-devel
%if 0%{?suse_version} > 1550
BuildRequires:  tensorflow-lite-devel >= 2.10
%else
BuildRequires:  tensorflow2-lite-devel >= 2.10
%endif
%endif
%if %{with compute_cl}
# Mesa-libOpenCl is required for tests
BuildRequires:  Mesa-libOpenCL
BuildRequires:  ocl-icd-devel
BuildRequires:  opencl-cpp-headers
BuildRequires:  opencl-headers
%endif
%if %{with armnn_onnx}
BuildRequires:  python3-onnx
%endif
%if %{with armnn_tests}
BuildRequires:  stb-devel
%endif
%if %{with PyArmnn}
BuildRequires:  python3-devel
BuildRequires:  python3-wheel
BuildRequires:  swig >= 4
%endif
%if %{with compute_cl}
Recommends:     Mesa-libOpenCL
%endif
%if %{with armnn_flatbuffers}
Requires:       libarmnnSerializer%{version_lib}%{?package_suffix} = %{version}
Requires:       libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix} = %{version}
%endif
%if %{with armnn_onnx}
Requires:       libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix} = %{version}
%endif
# Make sure we do not install both openCL and non-openCL (CPU only) versions.
%if "%{target}" == "opencl"
Conflicts:      armnn
%else
Conflicts:      armnn-opencl
%endif
ExclusiveArch:  aarch64 armv7l armv7hl x86_64

%description
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

%package devel
Summary:        Development headers and libraries for armnn
# Make sure we do not install both openCL and non-openCL (CPU only) versions.
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libarmnn%{version_lib}%{?package_suffix} = %{version}
Requires:       libarmnnBasePipeServer%{version_lib}%{?package_suffix} = %{version}
Requires:       libarmnnTestUtils%{version_lib_testutils}%{?package_suffix}
Requires:       libtimelineDecoder%{version_lib}%{?package_suffix} = %{version}
Requires:       libtimelineDecoderJson%{version_lib}%{?package_suffix} = %{version}
# Make sure we do not install both openCL and non-openCL (CPU only) versions.
%if "%{target}" == "opencl"
Conflicts:      armnn-devel
%else
Conflicts:      armnn-opencl-devel
%endif
%if %{with armnn_flatbuffers}
Requires:       libarmnnSerializer%{version_lib}%{?package_suffix} = %{version}
Requires:       libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix} = %{version}
%endif
%if %{with armnn_onnx}
Requires:       libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix} = %{version}
%endif

%description devel
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the development libraries and headers for armnn.

%package -n libarmnn%{version_lib}%{?package_suffix}
Summary:        libarmnn from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libarmnn%{version_lib}
%else
Conflicts:      libarmnn%{version_lib}-opencl
%endif

%description -n libarmnn%{version_lib}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libarmnn library from armnn.

%package -n libarmnnBasePipeServer%{version_lib}%{?package_suffix}
Summary:        libarmnnBasePipeServer from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libarmnnBasePipeServer%{version_lib}
%else
Conflicts:      libarmnnBasePipeServer%{version_lib}-opencl
%endif

%description -n libarmnnBasePipeServer%{version_lib}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libarmnnBasePipeServer library from armnn.

%package -n libarmnnTestUtils%{version_lib_testutils}%{?package_suffix}
Summary:        libarmnnTestUtils from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libarmnnTestUtils%{version_lib_testutils}
%else
Conflicts:      libarmnnTestUtils%{version_lib_testutils}-opencl
%endif

%description -n libarmnnTestUtils%{version_lib_testutils}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libarmnnTestUtils library from armnn.

%package -n libtimelineDecoder%{version_lib}%{?package_suffix}
Summary:        libtimelineDecoder from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libtimelineDecoder%{version_lib}
%else
Conflicts:      libtimelineDecoder%{version_lib}-opencl
%endif

%description -n libtimelineDecoder%{version_lib}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libtimelineDecoder library from armnn.

%package -n libtimelineDecoderJson%{version_lib}%{?package_suffix}
Summary:        libtimelineDecoderJson from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libtimelineDecoderJson%{version_lib}
%else
Conflicts:      libtimelineDecoderJson%{version_lib}-opencl
%endif

%description -n libtimelineDecoderJson%{version_lib}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libtimelineDecoder library from armnn.

%if %{with armnn_flatbuffers}
%package -n libarmnnSerializer%{version_lib}%{?package_suffix}
Summary:        libarmnnSerializer from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libarmnnSerializer%{version_lib}
%else
Conflicts:      libarmnnSerializer%{version_lib}-opencl
%endif

%description -n libarmnnSerializer%{version_lib}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libarmnnSerializer library from armnn.

%package -n libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix}
Summary:        libarmnnTfLiteParser from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libarmnnTfLiteParser%{version_lib_tfliteparser}
%else
Conflicts:      libarmnnTfLiteParser%{version_lib_tfliteparser}-opencl
%endif

%description -n libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libarmnnTfLiteParser library from armnn.
%endif

%if %{with armnn_onnx}
%package -n libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix}
Summary:        libarmnnOnnxParser from armnn
Group:          Development/Libraries/C and C++
%if "%{target}" == "opencl"
Conflicts:      libarmnnOnnxParser%{version_lib_onnxparser}
%else
Conflicts:      libarmnnOnnxParser%{version_lib_onnxparser}-opencl
%endif

%description -n libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix}
Arm NN is an inference engine for CPUs, GPUs and NPUs.
It bridges the gap between existing NN frameworks and the underlying IP.
It enables efficient translation of existing neural network frameworks,
such as TensorFlow Lite, allowing them to run efficiently – without
modification – across Arm Cortex CPUs and Arm Mali GPUs.

This package contains the libarmnnOnnxParser library from armnn.
%endif

%prep
%setup -q -n armnn-%{version}

%build
%if %{with armnn_onnx}
mkdir onnx_deps
PROTO=$(find %{_libdir} -name onnx.proto)
protoc $PROTO --proto_path=. --proto_path=%{_includedir} --proto_path=$(dirname $(find %{_libdir} -name onnx)) --cpp_out=./onnx_deps
%endif
%cmake \
  -DCMAKE_SKIP_RPATH=True \
  -DSHARED_BOOST=1 \
  -DCMAKE_CXX_FLAGS:STRING="%{optflags} -pthread -Wno-error=unused-result" \
  -DBOOST_LIBRARYDIR=%{_libdir} \
%if %{with armnn_onnx}
  -DBUILD_ONNX_PARSER=ON \
  -DONNX_GENERATED_SOURCES=../onnx_deps/ \
%else
  -DBUILD_ONNX_PARSER=OFF \
%endif
%if %{with armnn_flatbuffers}
  -DBUILD_ARMNN_SERIALIZER=ON \
  -DFLATC_DIR=%{_bindir} \
  -DFLATBUFFERS_INCLUDE_PATH=%{_includedir} \
  -DBUILD_TF_LITE_PARSER=ON \
  -DTfLite_Schema_INCLUDE_PATH=%{_includedir}/tensorflow/lite/schema/ \
  -DTF_LITE_SCHEMA_INCLUDE_PATH=%{_includedir}/tensorflow/lite/schema/ \
%else
  -DBUILD_ARMNN_SERIALIZER=OFF \
  -DBUILD_TF_LITE_PARSER=OFF \
%endif
%if %{with compute_neon} || %{with compute_cl}
  -DARMCOMPUTE_INCLUDE=%{_includedir} \
  -DHALF_INCLUDE=%{_includedir}/half \
  -DARMCOMPUTE_BUILD_DIR=%{_libdir} \
  -DARMCOMPUTE_ROOT=%{_prefix} \
%endif
%if %{with compute_neon}
  -DARMCOMPUTENEON=ON \
%else
  -DARMCOMPUTENEON=OFF \
%endif
%if %{with compute_cl}
  -DARMCOMPUTECL=ON \
  -DOPENCL_INCLUDE=%{_includedir} \
%else
  -DARMCOMPUTECL=OFF \
%endif
  -DTHIRD_PARTY_INCLUDE_DIRS=%{_includedir} \
%if %{with armnn_flatbuffers}
  -DBUILD_SAMPLE_APP=ON \
%else
  -DBUILD_SAMPLE_APP=OFF \
%endif
%if %{with armnn_tests}
  -DBUILD_UNIT_TESTS=ON \
  -DBUILD_TESTS=ON \
%else
  -DBUILD_UNIT_TESTS=OFF \
  -DBUILD_TESTS=OFF \
%endif
%if %{with PyArmnn}
  -DBUILD_PYTHON_WHL=ON \
  -DBUILD_PYTHON_SRC=ON \
%else
  -DBUILD_PYTHON_WHL=OFF \
  -DBUILD_PYTHON_SRC=OFF \
%endif


%if 0%{?suse_version} > 1500
%cmake_build
%else
%make_jobs
%endif
%if %{with armnn_tests}
pushd tests/
%if 0%{?suse_version} > 1500
%cmake_build
%else
%make_jobs
%endif
popd
%endif

%install
%cmake_install
%if %{with armnn_tests}
# Install tests manually
install -d %{buildroot}%{_bindir}
CP_ARGS="-Prf --preserve=mode,timestamps --no-preserve=ownership" \
find ./build/tests -maxdepth 1 -type f -executable -exec cp $CP_ARGS {} %{buildroot}%{_bindir} \;
%endif
%if %{with armnn_flatbuffers}
# Install Sample app
cp $CP_ARGS ./build/samples/SimpleSample %{buildroot}%{_bindir}
%endif
# Drop static libs - https://github.com/ARM-software/armnn/issues/514
rm -f  %{buildroot}%{_libdir}/*.a

# openCL UnitTests are failing in OBS due to the lack of openCL device
%if %{without compute_cl} && %{with armnn_tests}
%check
# Run tests
LD_LIBRARY_PATH="$(pwd)/build/" \
./build/UnitTests $UnitTestFlags
%endif

%post -n libarmnn%{version_lib}%{?package_suffix} -p /sbin/ldconfig
%postun -n libarmnn%{version_lib}%{?package_suffix} -p /sbin/ldconfig

%post -n libarmnnBasePipeServer%{version_lib}%{?package_suffix} -p /sbin/ldconfig
%postun -n libarmnnBasePipeServer%{version_lib}%{?package_suffix} -p /sbin/ldconfig

%post -n libarmnnTestUtils%{version_lib_testutils}%{?package_suffix} -p /sbin/ldconfig
%postun -n libarmnnTestUtils%{version_lib_testutils}%{?package_suffix} -p /sbin/ldconfig

%post -n libtimelineDecoderJson%{version_lib}%{?package_suffix} -p /sbin/ldconfig
%postun -n libtimelineDecoderJson%{version_lib}%{?package_suffix} -p /sbin/ldconfig

%post -n libtimelineDecoder%{version_lib}%{?package_suffix} -p /sbin/ldconfig
%postun -n libtimelineDecoder%{version_lib}%{?package_suffix} -p /sbin/ldconfig

%if %{with armnn_flatbuffers}
%post -n libarmnnSerializer%{version_lib}%{?package_suffix} -p /sbin/ldconfig
%postun -n libarmnnSerializer%{version_lib}%{?package_suffix} -p /sbin/ldconfig

%post -n libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix} -p /sbin/ldconfig
%postun -n libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix} -p /sbin/ldconfig
%endif

%if %{with armnn_onnx}
%post -n libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix} -p /sbin/ldconfig
%postun -n libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix} -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%if %{with armnn_tests}
%{_bindir}/ExecuteNetwork
%if %{with armnn_flatbuffers}
%{_bindir}/TfLite*-Armnn
%endif
%if %{with armnn_onnx}
%{_bindir}/Onnx*-Armnn
%endif
%if %{with armnn_flatbuffers}
%{_bindir}/SimpleSample
%endif
%endif

%files -n libarmnn%{version_lib}%{?package_suffix}
%{_libdir}/libarmnn.so.*

%files -n libarmnnBasePipeServer%{version_lib}%{?package_suffix}
%{_libdir}/libarmnnBasePipeServer.so.*

%files -n libarmnnTestUtils%{version_lib_testutils}%{?package_suffix}
%{_libdir}/libarmnnTestUtils.so.*

%files -n libtimelineDecoder%{version_lib}%{?package_suffix}
%{_libdir}/libtimelineDecoder.so.*

%files -n libtimelineDecoderJson%{version_lib}%{?package_suffix}
%{_libdir}/libtimelineDecoderJson.so.*

%if %{with armnn_flatbuffers}
%files -n libarmnnSerializer%{version_lib}%{?package_suffix}
%{_libdir}/libarmnnSerializer.so.*

%files -n libarmnnTfLiteParser%{version_lib_tfliteparser}%{?package_suffix}
%{_libdir}/libarmnnTfLiteParser.so.*
%endif

%if %{with armnn_onnx}
%files -n libarmnnOnnxParser%{version_lib_onnxparser}%{?package_suffix}
%{_libdir}/libarmnnOnnxParser.so.*
%endif

%files devel
%defattr(-,root,root)
%dir %{_includedir}/armnn/
%{_includedir}/armnn/*.hpp
%dir %{_includedir}/armnn/backends
%{_includedir}/armnn/backends/CMakeLists.txt
%{_includedir}/armnn/backends/*.hpp
%dir %{_includedir}/armnn/profiling
%{_includedir}/armnn/profiling/*.hpp
%dir %{_includedir}/armnn/profiling/client/
%dir %{_includedir}/armnn/profiling/client/include/
%{_includedir}/armnn/profiling/client/include/*.hpp
%dir %{_includedir}/armnn/profiling/client/include/backends/
%{_includedir}/armnn/profiling/client/include/backends/*.hpp
%dir %{_includedir}/armnn/profiling/common/
%dir %{_includedir}/armnn/profiling/common/include/
%{_includedir}/armnn/profiling/common/include/*.hpp
%dir %{_includedir}/armnn/utility
%{_includedir}/armnn/utility/*.hpp
%dir %{_includedir}/armnnUtils
%{_includedir}/armnnUtils/*.hpp
%dir %{_includedir}/armnnOnnxParser/
%{_includedir}/armnnOnnxParser/*.hpp
%dir %{_includedir}/armnnTfLiteParser/
%{_includedir}/armnnTfLiteParser/*.hpp
%dir %{_includedir}/armnnDeserializer/
%{_includedir}/armnnDeserializer/IDeserializer.hpp
%dir %{_includedir}/armnnSerializer/
%{_includedir}/armnnSerializer/ISerializer.hpp
%dir %{_includedir}/armnnTestUtils/
%{_includedir}/armnnTestUtils/*.hpp
%dir %{_libdir}/cmake/armnn
%{_libdir}/cmake/armnn/*
%{_libdir}/libarmnn.so
%{_libdir}/libarmnnBasePipeServer.so
%{_libdir}/libtimelineDecoder.so
%{_libdir}/libtimelineDecoderJson.so
%if %{with armnn_flatbuffers}
%{_libdir}/libarmnnSerializer.so
%{_libdir}/libarmnnTfLiteParser.so
%endif
%{_libdir}/libarmnnTestUtils.so
%if %{with armnn_onnx}
%{_libdir}/libarmnnOnnxParser.so
%endif

%changelog
* Tue Dec  3 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Remove downstream patches:
  * 0003-add-more-test-command-line-arguments.patch
  * 0005-add-armnn-mobilenet-test-example.patch
  * 0006-armnn-mobilenet-test-example.patch
  * 0009-command-line-options-for-video-port-selection.patch
  * 0010-armnnexamples-update-for-19.08-modifications.patch
  * armnn-fix_find_opencv.patch
* Mon Dec  2 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
-  Update to 24.11:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v24.11
- Drop upstream patch:
  * armnn-fix-armv7.patch
* Fri Sep  6 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on armv7:
  * armnn-fix-armv7.patch
* Tue Sep  3 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 24.08:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v24.08
* Tue Jun 18 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
-  Update to 24.05:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v24.05
* Wed Apr  3 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 24.02:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v24.02
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Dec  7 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 23.11:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v23.11
* Tue Sep  5 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
-  Update to 23.08:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v23.08
* Mon Jun 12 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 23.05:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v23.05
- Drop upstream patches:
  * armnn-fix-gcc13.patch
  * armnn-fix-gcc13-2.patch
  * 4cf40d7.diff
* Thu Apr 20 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add additionnal gcc13 fixes:
  * 4cf40d7.diff
  * armnn-fix-gcc13-2.patch
* Wed Apr  5 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update armnn-fix-gcc13.patch with upstream patch
* Tue Mar 21 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build with GCC13:
  * armnn-fix-gcc13.patch
* Wed Mar 15 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 23.02:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v23.02
- Drop upstream patches:
  * armnn-gh711.patch
  * armnn-281e97b.patch
* Wed Dec 14 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- tensorflow-lite >= 2.10 is only avaialble on Tumbleweed
* Wed Dec 14 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to use static libraries not object libraries for
  support library:
  * armnn-281e97b.patch
* Mon Nov 28 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 22.11:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v22.11
  * Add libarmnnTestUtils
- Add patch to fix build:
  * armnn-gh711.patch
* Tue Aug 30 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 22.08:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v22.08
- Drop upstream patch:
  * armnn-fix-gcc12.patch
* Tue May 31 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 22.05:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v22.05
- Add patch to fix build with GCC12 and new flatbuffers:
  * armnn-fix-gcc12.patch
* Tue Mar 15 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
-  Update to 22.02:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v22.02
  * Add libarmnnTestUtils
* Wed Dec  1 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 21.11:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v21.11
  * Main changes:
  - New capabilities and improve performance
  - ABI/API Changes
    The following front-end API changes have occurred during the
    implementation of 21.11 that users should be aware of before
    upgrading. Due to these changes we have bumped our ARMNN_VERSION
    to 27.0.0, the Delegate to 25.0.0 and also bumping
    our Parsers to 24.3.0 following Semantic Versioning guidelines.
- Drop upstream patches:
  * 96beb97.diff
  * febc20f.diff
  * e118e04.diff
  * 0011-update-doctest-for-glibc2.34.patch
* Mon Oct 25 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add upstream patch to fix stringop-overread error:
  * e118e04.diff
* Thu Oct 21 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add upstream patch to fix uninitialized var error:
  * febc20f.diff
- Remove most -Wno-error* flags which are not needed anymore
* Wed Oct 20 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add 0011-update-doctest-for-glibc2.34.patch: Update doctest to
  version 2.4.6 to allow Arm NN to build with glibc 2.34; patch
  taken from upstream commits 13d2e0d and 4ec6d42and rebased for
  current version.
* Thu Sep  9 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 21.08:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v21.08
  * Main changes:
  - new capabilities and improve performance:
  * Added the ability to import protected DMA Buffers and
    allow Arm NN to run inferences that are in Protected GPU Memory.
    As well as providing Custom Memory Allocator which supports
    importing malloc, Dma_buf and protected Dma buffers.
  * Users with multi core NPUs has been given the ability to pin
    inferences to selected cores giving them the ability to balance
    parallel workloads across the NPU and increase throughput.
  * Boost has been completely removed from the code base making
    Arm NN easier to integrate into other software stacks.
  * Added support for non-constant weights and biases on
    FullyConnected which lay the groundwork for supporting more models.
  * More operators supported on Arm NN, TfLite Parser, TfLite
    Delegate and Android NNAPI driver.
- Drop upstream patch:
  * armnn-fix-include.patch
* Fri Jul 16 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add '-Wno-error=stringop-overread' to workaround build error
  with GCC11 with openCL enabled
* Tue Jul 13 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add '-Wno-error=uninitialized -Wno-error=array-bounds' to
  workaround build issues with GCC11 - https://github.com/ARM-software/armnn/issues/548
* Tue May 25 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix libarmnnOnnxParser version
* Fri May 21 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 21.05:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v21.05
  * Main changes:
  - new capabilities to allow users attain higher performance by:
  * Making the Arm NN Core thread safe opening the possibility of
    running multiple inferences on the same model in parallel
    software threads.
  * Allowing graphs on the GPU backend import their input and
    output buffers either from correctly aligned main memory or
    from kernel memory exposed as a dma_buf, thus reducing memory
    usage and saving the time involved in copying data into and
    out of the GPU memory space.
  - In addition to this, support was added to allow the MobileBERT
    network to be parsed and run.
  - Finally three deprecated components: the Tensorflow Parser,
    the Caffe Parser and the Arm NN Quantizer tool, were removed
- Add patch to fix include path:
  * armnn-fix-include.patch
- Disable armnn-extratests as it fails to build with current version
* Mon Mar 29 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 21.02:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v21.02
- Drop upstream patch:
  * c5c40fe.diff
* Mon Feb 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix instalaltion of cmake files with an upstream patch:
  * c5c40fe.diff
* Mon Jan 25 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patch to fix tflite parser when built against
  tensorflow 2.4:
  * 96beb97.diff
* Wed Dec  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 20.11:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v20.11
- Refresh patch to handle boost::variant to mapbox::util::variant update:
  * 0006-armnn-mobilenet-test-example.patch
* Fri Sep  4 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add python support, disabled for now as it does not install
  files atm
* Fri Sep  4 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Package libtimelineDecoderJson
* Thu Sep  3 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 20.08:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v20.08
- Refresh patch:
  * 0005-add-armnn-mobilenet-test-example.patch
- Drop upstream patch:
  * armnn-fix-catch.patch
- Disable ONNX on Tumbleweed since there is a compatibility issue
  with ONNX 1.7.0, see: https://github.com/ARM-software/armnn/issues/419
* Wed Jun 17 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only where ComputeLibrary is built:
  aarch64 armv7 and x86_64
* Thu Jun  4 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Unify Leap/SLE options
- Update to 20.05:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v20.05
- Drop upstream patch:
  * armnn-enable-use-of-arm-compute-shared-library.patch
- Refresh patch:
  * 0003-add-more-test-command-line-arguments.patch
- Add new patch to fix build with gcc10:
  * armnn-fix-catch.patch
- Package new libtimelineDecode and libarmnnBasePipeServer
* Thu May 28 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Apply boost link fixes only for armnn_extra_tests
- Apply patches for armnn_extra_tests only when
  armnn_extra_tests is built
* Tue Mar 31 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable RPATH to fix build on Leap15.2/SLE15SP2
* Tue Mar 24 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add '-Wno-error=deprecated-declarations' to fix build with latest
  protobuf 3.11.x (Tumbleweed)
  https://github.com/ARM-software/armnn/issues/366
- Use python-onnx package instead of python-onnx-devel, since it
  is now a single package.
* Wed Mar 11 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on Leap 15.2
* Mon Mar  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 20.02:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v20.02
  * Drop upstream patch:
  - armnn-fix_include.patch
  * Refresh patch:
  - 0006-armnn-mobilenet-test-example.patch
  * Replace downstream patch:
  - 0007-enable-use-of-arm-compute-shared-library.patch
    by upstream patch:
  - armnn-enable-use-of-arm-compute-shared-library.patch
  * Add 'vim' as BuildRequires since it needs 'xxd' tool
- Use TensorFlow 2 also on Leap 15.2 / SLE15SP2
* Mon Feb 10 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use Tensorflow 2.x only for Tumbleweed, as TensorFlow2 is not
  available in Leap 15.2
- Skip some tests if TensorFlow < 1.14 is used
* Tue Jan 28 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable ONNX on Leap 15.2
* Tue Jan 28 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use tensorflow2 as armnn 19.11 now requires TensorFlow >= 1.14
* Mon Jan 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable ArmnnConverter and ArmnnQuantizer packaging by default
  as it requires libQuantizer.so to be packaged, which is not yet
* Tue Jan 14 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Package ArmnnConverter and ArmnnQuantizer
* Tue Jan 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- ExcludeArch %%ix86: Parts of the build deps (tensorflow/bazel) are
  not supported on ix86.
* Fri Dec  6 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 19.11:
  * Changelog: https://github.com/ARM-software/armnn/releases/tag/v19.11
- Remove upstreamed patches:
  * armnn-generate-versioned-library.patch
  * armnn-fix_boost.patch
  * armnn-fix_arm32_dep.patch
  * armnn-fix_arm32.patch
- Add patch to fix include:
  * armnn-fix_include.patch
* Mon Nov 25 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- tensorflow-devel package now includes *.pb.* files, so
  remove TensorFlow parser build workaround:
  * armnn-fix_tensorflow_link.patch
* Mon Oct 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add a conflict between armnn-extratests and armnn-opencl-extratests
* Mon Oct 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add a conflict between armnn-devel and armnn-opencl-devel
* Mon Oct 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable ONNX for Tumbleweed
* Thu Oct 17 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add downstream ArmnnExamples in a separate '-extratests' package
  with patches:
  * 0003-add-more-test-command-line-arguments.patch
  * 0005-add-armnn-mobilenet-test-example.patch
  * 0006-armnn-mobilenet-test-example.patch
  * 0007-enable-use-of-arm-compute-shared-library.patch
  * 0009-command-line-options-for-video-port-selection.patch
  * 0010-armnnexamples-update-for-19.08-modifications.patch
- Fix build when extratests are disabled
  * armnn-fix_find_opencv.patch
* Mon Oct  7 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Replace patch with an upstreamable version:
  * armnn-generate-versioned-library.patch
* Tue Oct  1 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add ONNX Parser support (disabled by default as there is no
  official ONNX package yet)
* Tue Oct  1 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Re-enable Tensorflow on Tumbleweed as boo#1151150 is now fixed
* Thu Sep 19 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints
* Wed Sep 18 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable openCL only on a separate flavor as runtime requires
  libOpenCL.so, libGLES_mali.so, or libmali.so
* Wed Sep 18 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable openCL support
- Disable UnitTests when openCL support is enabled as it fails
  on OBS workers
* Wed Sep 18 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patches to make UnitTests to pass on armv7:
  * armnn-fix_arm32.patch
  * armnn-fix_arm32_dep.patch
* Thu Sep  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable TensorFlow as on 15.1 only x86_64 succeed and on TW we
  have incompatibility with protobuf (3.8.0 in TW and
  Tensorflow uses 3.6.1 internally) - boo#1151150
* Thu Sep  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 19.08:
- Changelog: https://github.com/ARM-software/armnn/releases/tag/v19.08
- Remove upstreamed patch:
  * armnn-fix_quantizer_link.patch
  * armnn-fix_caffe_parser_with_new_protobuf.patch
- Refresh patch:
  * armnn-generate-versioned-library.patch
- Drop patches not needed anymore:
  * armnn-remove_broken_std_move.patch
  * armnn-fix_build_with_gcc9.patch
* Wed Sep  4 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO until lto link is fixed
  https://github.com/ARM-software/armnn/issues/251
* Tue Jun 18 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build in Tumbleweed, with latest protobuf:
  * armnn-fix_caffe_parser_with_new_protobuf.patch
* Tue Jun 11 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable Tensorflow parser
- Fix link with Tensorflow:
  * armnn-fix_tensorflow_link.patch
* Wed Jun  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build and package libarmnnTfLiteParser
- Fix libarmnnQuantizer build with:
  * armnn-fix_quantizer_link.patch
* Tue Jun  4 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid OOM errors
* Mon Jun  3 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 19.05:
- Changelog: https://github.com/ARM-software/armnn/releases/tag/v19.05
- Remove upstreamed patch:
  * armnn-fix_stb_include.patch
- Rebase patch:
  * armnn-generate-versioned-library.patch
- Update patch:
  * armnn-remove_broken_std_move.patch
* Mon Jun  3 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on Tumbleweed with:
  * armnn-fix_build_with_gcc9.patch
* Wed May 29 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on Tumbleweed with:
  * armnn-remove_broken_std_move.patch
* Wed May 29 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Call ldconfig in post/postun for libarmnnCaffeParser
* Mon May 27 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable and fix Caffe parser
- Use %%cmake_build macro
* Fri Apr 19 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add compute_cl option, disabled by default since check fails as
  no openCL are enabled in OBS
* Thu Apr 11 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Split libarmnn and libarmnnSerializer to separate packages
* Thu Apr 11 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to have versionned libs:
  * armnn-generate-versioned-library.patch
- Package versionned libs
* Tue Apr  9 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable NEON backend on AArch64
- Add patch to enable use of shared lib for ComputeLibrary:
  * 0007-enable-use-of-arm-compute-shared-library.patch
* Tue Mar 26 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 19.02
- Remove upstreamed patch:
  * armnn-fix_catching_polymorphic_type.patch
* Thu Jan 17 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 18.11
- Add patch to fix build:
  * armnn-fix_catching_polymorphic_type.patch
  * armnn-fix_boost.patch
  * armnn-fix_stb_include.patch
* Thu Sep 13 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Initial version 18.08
